==> haskell-bytestring-tree-builder-0.2.7.13-40.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-tree-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytestring-tree-builder
version:              0.2.7.13
visibility:           public
id:                   bytestring-tree-builder-0.2.7.13-1q3iZsjo0U96qEOokA5GwK
key:                  bytestring-tree-builder-0.2.7.13-1q3iZsjo0U96qEOokA5GwK
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/bytestring-tree-builder
synopsis:
    A very efficient ByteString builder implementation based on the binary tree

description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the benchmarks>
    this builder implementation beats all the alternatives.
    It is especially well-suited for generating strict bytestrings,
    beating the standard builder by at least the factor of 4.

category:             ByteString
abi:                  74b6f62f6a1626986387ce3b4bf55563
exposed:              True
exposed-modules:      ByteString.TreeBuilder
hidden-modules:
    ByteString.TreeBuilder.Poker ByteString.TreeBuilder.Prelude
    ByteString.TreeBuilder.Tree

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/bytestring-tree-builder-0.2.7.13

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/bytestring-tree-builder-0.2.7.13

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/bytestring-tree-builder-0.2.7.13

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-tree-builder
hs-libraries:         HSbytestring-tree-builder-0.2.7.13-1q3iZsjo0U96qEOokA5GwK
depends:              base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-tree-builder/html/bytestring-tree-builder.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-tree-builder/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-tree-builder-0.2.7.13-41-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-tree-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytestring-tree-builder
version:              0.2.7.13
visibility:           public
id:                   bytestring-tree-builder-0.2.7.13-FwMdcdGvXWgJQbnsWeUFWv
key:                  bytestring-tree-builder-0.2.7.13-FwMdcdGvXWgJQbnsWeUFWv
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/bytestring-tree-builder
synopsis:
    A very efficient ByteString builder implementation based on the binary tree

description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the benchmarks>
    this builder implementation beats all the alternatives.
    It is especially well-suited for generating strict bytestrings,
    beating the standard builder by at least the factor of 4.

category:             ByteString
abi:                  68d2f9d342d231d0ea45d699fac7d91b
exposed:              True
exposed-modules:      ByteString.TreeBuilder
hidden-modules:
    ByteString.TreeBuilder.Poker ByteString.TreeBuilder.Prelude
    ByteString.TreeBuilder.Tree

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/bytestring-tree-builder-0.2.7.13

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/bytestring-tree-builder-0.2.7.13

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/bytestring-tree-builder-0.2.7.13

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-tree-builder
hs-libraries:         HSbytestring-tree-builder-0.2.7.13-FwMdcdGvXWgJQbnsWeUFWv
depends:              base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-tree-builder/html/bytestring-tree-builder.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-tree-builder/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
